@@ -298,7 +298,7 @@ AppWindow::finish_editing( bool opt_save )
     Lifeograph::s_internaloperation++;
     panel_main->handle_logout();
     panel_diary->handle_logout();
-    m_entry_view->get_buffer()->handle_logout();
+    m_entry_view->handle_logout();
     panel_extra->handle_logout();
 
     if( Lifeograph::loginstatus == Lifeograph::LOGGED_IN )
@@ -458,7 +458,8 @@ AppWindow::login()
             Lifeograph::icons->month_32 =
                     Gdk::Pixbuf::create_from_file( icon_dir + "/month-32.png" );
 
-            Gtk::IconInfo ii = theme->lookup_icon( "filter-16-symbolic", 16 );
+            Gtk::IconInfo ii = theme->lookup_icon( "filter-16-symbolic", 16,
+                                                   Gtk::IconLookupFlags( 0 ) );
             bool res;
             Lifeograph::icons->filter_16 = ii.load_symbolic( m_paned_main->get_style_context(),
                                                              res );
